@@ -55,9 +55,12 @@ class FirewallIPSet(object):
     def has_ipsets(self):
         return len(self._ipsets) > 0
 
-    def get_ipset(self, name):
+    def get_ipset(self, name, applied=False):
         self.check_ipset(name)
-        return self._ipsets[name]
+        obj = self._ipsets[name]
+        if applied:
+            self.check_applied_obj(obj)
+        return obj
 
     def _error2warning(self, f, name, *args):
         # transform errors into warnings
@@ -92,7 +95,10 @@ class FirewallIPSet(object):
             obj = self._ipsets[name]
             obj.applied = False
 
+            log.debug1("Applying ipset '%s'" % name)
+
             if name in active and ("timeout" not in obj.options or \
+                                   obj.options["timeout"] == "0" or \
                                    obj.type != active[name][0] or \
                                    rm_def_cr_opts(obj.options) != \
                                    active[name][1]):
@@ -110,7 +116,8 @@ class FirewallIPSet(object):
                     log.error(msg)
                 else:
                     obj.applied = True
-                    if "timeout" not in obj.options:
+                    if "timeout" not in obj.options or \
+                       obj.options["timeout"] != "0":
                         # no entries visible for ipsets with timeout
                         continue
 
@@ -135,12 +142,30 @@ class FirewallIPSet(object):
     # TYPE
 
     def get_type(self, name):
-        return self.get_ipset(name).type
+        return self.get_ipset(name, applied=True).type
+
+    # DIMENSION
+    def get_dimension(self, name):
+        return len(self.get_ipset(name, applied=True).type.split(","))
+
+    # APPLIED
+
+    def is_applied(self, name):
+        return self.get_ipset(name).applied == True
+
+    def check_applied(self, name):
+        obj = self.get_ipset(name)
+        self.check_applied_obj(obj)
+
+    def check_applied_obj(self, obj):
+        if not obj.applied:
+            raise FirewallError(
+                errors.NOT_APPLIED, obj.name)
 
     # OPTIONS
 
     def get_family(self, name):
-        obj = self.get_ipset(name)
+        obj = self.get_ipset(name, applied=True)
         if "family" in obj.options:
             if obj.options["family"] == "inet6":
                 return "ipv6"
@@ -155,8 +180,8 @@ class FirewallIPSet(object):
         pass
 
     def add_entry(self, name, entry):
-        obj = self.get_ipset(name)
-        if "timeout" in obj.options:
+        obj = self.get_ipset(name, applied=True)
+        if "timeout" in obj.options and obj.options["timeout"] != "0":
             # no entries visible for ipsets with timeout
             raise FirewallError(errors.IPSET_WITH_TIMEOUT, name)
 
@@ -172,13 +197,13 @@ class FirewallIPSet(object):
                       (entry, obj.name))
             log.error(msg)
         else:
-            if "timeout" not in obj.options:
+            if "timeout" not in obj.options or obj.options["timeout"] == "0":
                 # no entries visible for ipsets with timeout
                 obj.entries.append(entry)
 
     def remove_entry(self, name, entry):
-        obj = self.get_ipset(name)
-        if "timeout" in obj.options:
+        obj = self.get_ipset(name, applied=True)
+        if "timeout" in obj.options and obj.options["timeout"] != "0":
             # no entries visible for ipsets with timeout
             raise FirewallError(errors.IPSET_WITH_TIMEOUT, name)
 
@@ -193,29 +218,25 @@ class FirewallIPSet(object):
                       (entry, obj.name))
             log.error(msg)
         else:
-            if "timeout" not in obj.options:
+            if "timeout" not in obj.options or obj.options["timeout"] == "0":
                 # no entries visible for ipsets with timeout
                 obj.entries.remove(entry)
 
     def query_entry(self, name, entry):
-        obj = self.get_ipset(name)
-        if "timeout" in obj.options:
+        obj = self.get_ipset(name, applied=True)
+        if "timeout" in obj.options and obj.options["timeout"] != "0":
             # no entries visible for ipsets with timeout
             raise FirewallError(errors.IPSET_WITH_TIMEOUT, name)
 
         return entry in obj.entries
 
     def get_entries(self, name):
-        obj = self.get_ipset(name)
-        if "timeout" in obj.options:
-            # no entries visible for ipsets with timeout
-            raise FirewallError(errors.IPSET_WITH_TIMEOUT, name)
-
+        obj = self.get_ipset(name, applied=True)
         return obj.entries
 
     def set_entries(self, name, entries):
-        obj = self.get_ipset(name)
-        if "timeout" in obj.options:
+        obj = self.get_ipset(name, applied=True)
+        if "timeout" in obj.options and obj.options["timeout"] != "0":
             # no entries visible for ipsets with timeout
             raise FirewallError(errors.IPSET_WITH_TIMEOUT, name)
 
