@@ -63,8 +63,15 @@ class IO_Object(object):
         self.check_config(conf)
         for i,(element,dummy) in enumerate(self.IMPORT_EXPORT_STRUCTURE):
             if isinstance(conf[i], list):
-                # remove duplicates
-                setattr(self, element, copy.deepcopy(list(set(conf[i]))))
+                # remove duplicates without changing the order
+                _conf = [ ]
+                _set = set()
+                for x in conf[i]:
+                    if x not in _set:
+                        _conf.append(x)
+                        _set.add(x)
+                del _set
+                setattr(self, element, copy.deepcopy(_conf))
             else:
                 setattr(self, element, copy.deepcopy(conf[i]))
 
